pb

package
v0.0.0-...-1c196b6 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 31, 2024 License: MIT Imports: 8 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var (
	OneFileStatus_name = map[int32]string{
		0: "UNKNOWN",
		1: "NOT_STARTED",
		2: "IN_PROGRESS",
		3: "COMPLETE",
		4: "FAILED",
	}
	OneFileStatus_value = map[string]int32{
		"UNKNOWN":     0,
		"NOT_STARTED": 1,
		"IN_PROGRESS": 2,
		"COMPLETE":    3,
		"FAILED":      4,
	}
)

Enum value maps for OneFileStatus.

var File_service_proto protoreflect.FileDescriptor
var Transcode_ServiceDesc = grpc.ServiceDesc{
	ServiceName: "Transcode",
	HandlerType: (*TranscodeServer)(nil),
	Methods: []grpc.MethodDesc{
		{
			MethodName: "BeginOneFile",
			Handler:    _Transcode_BeginOneFile_Handler,
		},
		{
			MethodName: "CheckOneFile",
			Handler:    _Transcode_CheckOneFile_Handler,
		},
	},
	Streams:  []grpc.StreamDesc{},
	Metadata: "service.proto",
}

Transcode_ServiceDesc is the grpc.ServiceDesc for Transcode service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)

Functions

func RegisterTranscodeServer

func RegisterTranscodeServer(s grpc.ServiceRegistrar, srv TranscodeServer)

Types

type BeginOneFileReply

type BeginOneFileReply struct {
	Key *OneFileKey `protobuf:"bytes,1,opt,name=key,proto3" json:"key,omitempty"`
	// contains filtered or unexported fields
}

func (*BeginOneFileReply) Descriptor deprecated

func (*BeginOneFileReply) Descriptor() ([]byte, []int)

Deprecated: Use BeginOneFileReply.ProtoReflect.Descriptor instead.

func (*BeginOneFileReply) GetKey

func (x *BeginOneFileReply) GetKey() *OneFileKey

func (*BeginOneFileReply) ProtoMessage

func (*BeginOneFileReply) ProtoMessage()

func (*BeginOneFileReply) ProtoReflect

func (x *BeginOneFileReply) ProtoReflect() protoreflect.Message

func (*BeginOneFileReply) Reset

func (x *BeginOneFileReply) Reset()

func (*BeginOneFileReply) String

func (x *BeginOneFileReply) String() string

type BeginOneFileRequest

type BeginOneFileRequest struct {
	InPath  string `protobuf:"bytes,1,opt,name=in_path,json=inPath,proto3" json:"in_path,omitempty"`
	OutPath string `protobuf:"bytes,2,opt,name=out_path,json=outPath,proto3" json:"out_path,omitempty"`
	// contains filtered or unexported fields
}

func (*BeginOneFileRequest) Descriptor deprecated

func (*BeginOneFileRequest) Descriptor() ([]byte, []int)

Deprecated: Use BeginOneFileRequest.ProtoReflect.Descriptor instead.

func (*BeginOneFileRequest) GetInPath

func (x *BeginOneFileRequest) GetInPath() string

func (*BeginOneFileRequest) GetOutPath

func (x *BeginOneFileRequest) GetOutPath() string

func (*BeginOneFileRequest) ProtoMessage

func (*BeginOneFileRequest) ProtoMessage()

func (*BeginOneFileRequest) ProtoReflect

func (x *BeginOneFileRequest) ProtoReflect() protoreflect.Message

func (*BeginOneFileRequest) Reset

func (x *BeginOneFileRequest) Reset()

func (*BeginOneFileRequest) String

func (x *BeginOneFileRequest) String() string

type CheckOneFileReply

type CheckOneFileReply struct {
	Key    *OneFileKey   `protobuf:"bytes,1,opt,name=key,proto3" json:"key,omitempty"`
	Status OneFileStatus `protobuf:"varint,2,opt,name=status,proto3,enum=OneFileStatus" json:"status,omitempty"`
	// contains filtered or unexported fields
}

func (*CheckOneFileReply) Descriptor deprecated

func (*CheckOneFileReply) Descriptor() ([]byte, []int)

Deprecated: Use CheckOneFileReply.ProtoReflect.Descriptor instead.

func (*CheckOneFileReply) GetKey

func (x *CheckOneFileReply) GetKey() *OneFileKey

func (*CheckOneFileReply) GetStatus

func (x *CheckOneFileReply) GetStatus() OneFileStatus

func (*CheckOneFileReply) ProtoMessage

func (*CheckOneFileReply) ProtoMessage()

func (*CheckOneFileReply) ProtoReflect

func (x *CheckOneFileReply) ProtoReflect() protoreflect.Message

func (*CheckOneFileReply) Reset

func (x *CheckOneFileReply) Reset()

func (*CheckOneFileReply) String

func (x *CheckOneFileReply) String() string

type CheckOneFileRequest

type CheckOneFileRequest struct {
	Key *OneFileKey `protobuf:"bytes,1,opt,name=key,proto3" json:"key,omitempty"`
	// contains filtered or unexported fields
}

func (*CheckOneFileRequest) Descriptor deprecated

func (*CheckOneFileRequest) Descriptor() ([]byte, []int)

Deprecated: Use CheckOneFileRequest.ProtoReflect.Descriptor instead.

func (*CheckOneFileRequest) GetKey

func (x *CheckOneFileRequest) GetKey() *OneFileKey

func (*CheckOneFileRequest) ProtoMessage

func (*CheckOneFileRequest) ProtoMessage()

func (*CheckOneFileRequest) ProtoReflect

func (x *CheckOneFileRequest) ProtoReflect() protoreflect.Message

func (*CheckOneFileRequest) Reset

func (x *CheckOneFileRequest) Reset()

func (*CheckOneFileRequest) String

func (x *CheckOneFileRequest) String() string

type OneFileKey

type OneFileKey struct {
	InPath   string `protobuf:"bytes,1,opt,name=in_path,json=inPath,proto3" json:"in_path,omitempty"`
	OutPath  string `protobuf:"bytes,2,opt,name=out_path,json=outPath,proto3" json:"out_path,omitempty"`
	Instance string `protobuf:"bytes,3,opt,name=instance,proto3" json:"instance,omitempty"`
	// contains filtered or unexported fields
}

Uniquely describe a single-file transcode.

func (*OneFileKey) Descriptor deprecated

func (*OneFileKey) Descriptor() ([]byte, []int)

Deprecated: Use OneFileKey.ProtoReflect.Descriptor instead.

func (*OneFileKey) GetInPath

func (x *OneFileKey) GetInPath() string

func (*OneFileKey) GetInstance

func (x *OneFileKey) GetInstance() string

func (*OneFileKey) GetOutPath

func (x *OneFileKey) GetOutPath() string

func (*OneFileKey) ProtoMessage

func (*OneFileKey) ProtoMessage()

func (*OneFileKey) ProtoReflect

func (x *OneFileKey) ProtoReflect() protoreflect.Message

func (*OneFileKey) Reset

func (x *OneFileKey) Reset()

func (*OneFileKey) String

func (x *OneFileKey) String() string

type OneFileStatus

type OneFileStatus int32
const (
	OneFileStatus_UNKNOWN     OneFileStatus = 0
	OneFileStatus_NOT_STARTED OneFileStatus = 1
	OneFileStatus_IN_PROGRESS OneFileStatus = 2
	OneFileStatus_COMPLETE    OneFileStatus = 3
	OneFileStatus_FAILED      OneFileStatus = 4
)

func (OneFileStatus) Descriptor

func (OneFileStatus) Enum

func (x OneFileStatus) Enum() *OneFileStatus

func (OneFileStatus) EnumDescriptor deprecated

func (OneFileStatus) EnumDescriptor() ([]byte, []int)

Deprecated: Use OneFileStatus.Descriptor instead.

func (OneFileStatus) Number

func (OneFileStatus) String

func (x OneFileStatus) String() string

func (OneFileStatus) Type

type TranscodeClient

type TranscodeClient interface {
	BeginOneFile(ctx context.Context, in *BeginOneFileRequest, opts ...grpc.CallOption) (*BeginOneFileReply, error)
	CheckOneFile(ctx context.Context, in *CheckOneFileRequest, opts ...grpc.CallOption) (*CheckOneFileReply, error)
}

TranscodeClient is the client API for Transcode service.

For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.

func NewTranscodeClient

func NewTranscodeClient(cc grpc.ClientConnInterface) TranscodeClient

type TranscodeServer

type TranscodeServer interface {
	BeginOneFile(context.Context, *BeginOneFileRequest) (*BeginOneFileReply, error)
	CheckOneFile(context.Context, *CheckOneFileRequest) (*CheckOneFileReply, error)
	// contains filtered or unexported methods
}

TranscodeServer is the server API for Transcode service. All implementations must embed UnimplementedTranscodeServer for forward compatibility

type UnimplementedTranscodeServer

type UnimplementedTranscodeServer struct {
}

UnimplementedTranscodeServer must be embedded to have forward compatible implementations.

func (UnimplementedTranscodeServer) BeginOneFile

func (UnimplementedTranscodeServer) CheckOneFile

type UnsafeTranscodeServer

type UnsafeTranscodeServer interface {
	// contains filtered or unexported methods
}

UnsafeTranscodeServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to TranscodeServer will result in compilation errors.

Jump to